@echo off
REM ---------------------------------------------------------------------------
REM
REM  Copyright (c) Intel Corporation, 2003 - 2009 All Rights Reserved.
REM
REM  File:      checkes.bat
REM
REM  Contents:  A batch file which checks for the existance of a Trusted Root
REM		certificate authority and creates one if necessary. 
REM		Afterwards, it creates remote and local Intel(R) AMT client 
REM 		certificates and an MPS certificate, all signed with the trusted 
REM		root certificate previously generated.
REM
REM ----------------------------------------------------------------------------


REM ######################################################################
REM ###                                                                ###
REM ### This batch is called by the Configuration Server program       ###
REM ### in order to check if the trusted root CA is ready for use.     ###
REM ### you may customize this script and modify the defaults          ###
REM ### at your own risk.                                              ###
REM ###                                                                ###
REM ######################################################################

REM ----------------------------------------------------------------------
REM The following environment parameters can be customized.
REM Note that they need to be coordinated with the appropriate 
REM .conf.xml file in order to achieve properly working environment.
REM ----------------------------------------------------------------------
set TRUSTED_ROOT_CRL_DISTRIBUTION_POINT=URI:http://trusted_root_crls.com
set REMOTE_CLIENT_CN=management_console.intel.com
set LOCAL_CLIENT_CN=acme_app.intel.com
set MPS_CN=mps.intel.com
set PKCS12_PASSWORD=qwerty
REM ----------------------------------------------------------------------
set exitCode=0

set PATH=%PATH%;../openSSL

IF NOT EXIST "trusted_rootCA" goto create
IF NOT EXIST "remote_client" goto create
IF NOT EXIST "local_client" goto create
IF NOT EXIST "MPS" goto create

echo Check Trusted-Root passed

goto end

:create
echo Configuration server needs a Trusted Root CA certificate in order
echo to be able to set up Intel(R) AMT devices for TLS client authentication.
echo You can create demo trusted root CA and have it sign demo remote 
echo and local client certificates.
echo The certificates generated in this script should ONLY be used for testing
echo and demonstrational purposes !
set exitCode=2
yesno "Create a demo Trusted Root CA and use it to sign client certificates [Y/n] ?" Y
IF NOT errorlevel 1 goto end
set exitCode=0

set CALLER_WAITS_ON_EXIT=1
call start /WAIT trusted_rootCA_gen.bat
call start /WAIT remote_client_req.bat
call start /WAIT remote_client_sign.bat
call start /WAIT remote_client_export.bat
call start /WAIT local_client_req.bat
call start /WAIT local_client_sign.bat
call start /WAIT local_client_export.bat
call start /WAIT MPS_cert_req.bat
call start /WAIT MPS_cert_sign.bat

:end
:exit %exitCode%