@echo off
REM ---------------------------------------------------------------------------
REM
REM  Copyright (c) Intel Corporation, 2003 - 2009 All Rights Reserved.
REM
REM  File:      certgen.bat
REM
REM  Contents:  batch file which creates a certificate for the provisioned 
REM				device. 
REM
REM ----------------------------------------------------------------------------

REM #######################################################################
REM ###                                                          			       	###
REM ### This script is called by the Configuration Server program       		###
REM ### in order to generate a Auditing certificate for the device being         		###
REM ### provisioned. 							###
REM ### you may customize this script and modify the defaults           			###
REM ### at your own risk.                                               				###
REM ###                                                                 				###
REM #######################################################################

setlocal

set PATH=%PATH%;../openSSL
set DAYS=-days 365
set CASUB=.\subCA
set AuditPath=.\AuditCert

IF "%PROVISIONING_KEY_FILE%"==""  SET PROVISIONING_KEY_FILE=%AuditPath%\Auditkey.pem
IF "%PROVISIONING_CERT_FILE%"=="" SET PROVISIONING_CERT_FILE=%AuditPath%\Auditcert.pem
IF "%PROVISIONING_RSA_KEY_BITS%"=="" SET PROVISIONING_RSA_KEY_BITS=2048

REM ### Create dir ####
mkdir %AuditPath%

REM ### Create request ###
openssl req -config ..\secConfig\Auditor.cfg -newkey rsa:%PROVISIONING_RSA_KEY_BITS% -keyout %PROVISIONING_KEY_FILE% -out %AuditPath%\Auditreq.pem %DAYS% 

REM ### Sign request ###
del /q %CASUB%\serial.old %CASUB%\index.txt.old %CASUB%\index.txt.attr.old

set SSLEAY_CONFIG=-config ../openSSL/openssl_sub.cfg

openssl ca %SSLEAY_CONFIG% -policy policy_anything -out %PROVISIONING_CERT_FILE% -infiles %AuditPath%\Auditreq.pem < yy.txt

openssl x509 -in %PROVISIONING_CERT_FILE% -inform PEM -out %AuditPath%\Auditcert.der -outform DER

REM -- Convet to an MS CERT format (optional) --
REM openssl x509 -in Auditcert.pem -inform PEM -out %AuditPath%\Auditcert.x509.cer -outform PEM

endlocal
goto end

:nouuid
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_UUID variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo .
pause 
goto end

:nohostname
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_HOSTNAME variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo .
pause 
goto end

:nodomain
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_DOMAIN variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo .
pause 
goto end

:nokeysize
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_RSA_KEY_BITS variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo .
pause 

:end
IF NOT %CALLER_WAITS_ON_EXIT%=="" EXIT
