@echo off
REM ---------------------------------------------------------------------------
REM
REM  Copyright (c) Intel Corporation, 2003 - 2010 All Rights Reserved.
REM
REM  File:      certgen.bat
REM
REM  Contents:  batch file which creates a certificate for the provisioned 
REM				device. 
REM
REM ----------------------------------------------------------------------------

REM #######################################################################
REM ###                                                                 ###
REM ### This script is called by the Configuration Server program       ###
REM ### in order to generate a certificate for the device being         ###
REM ### provisioned. The batch is called by genCertChain.bat which      ###
REM ### uses the certificate created here to make a trust chain         ###
REM ### starting at the root CA down to the device's certificate (the   ###
REM ### one created here).                                              ###
REM ### you may customize this script and modify the defaults           ###
REM ### at your own risk.                                               ###
REM ###                                                                 ###
REM #######################################################################

set exitCode=0

setlocal

set PATH=%PATH%;../openSSL
set DAYS=-days 365
set CASUB=.\subCA

IF "%PROVISIONING_KEY_FILE%"==""  SET PROVISIONING_KEY_FILE=newkey.pem
IF "%PROVISIONING_CERT_FILE%"=="" SET PROVISIONING_CERT_FILE=newcert.pem
IF "%PROVISIONING_SIGNATURE_ALGORITHM%"=="" SET PROVISIONING_SIGNATURE_ALGORITHM=md5
IF "%PROVISIONING_UUID%"==""  SET PROVISIONING_UUID="c2c1c0bf-c4c3-c6c5-c7c8-c9cacbcccdce"
IF "%PROVISIONING_HOSTNAME%"=="" SET PROVISIONING_HOSTNAME="ct"
IF "%PROVISIONING_DOMAIN%"=="" SET PROVISIONING_DOMAIN="intel.com"
IF "%PROVISIONING_RSA_KEY_BITS%"=="" SET PROVISIONING_RSA_KEY_BITS=2048



REM ### Create request ###
openssl req -config ..\secConfig\Uss.cfg -newkey rsa:%PROVISIONING_RSA_KEY_BITS% -keyout %PROVISIONING_KEY_FILE% -out newreq.pem %DAYS%
if not %errorlevel%==0 goto req_err

del /q %CASUB%\serial.old %CASUB%\index.txt.old %CASUB%\index.txt.attr.old

set SSLEAY_CONFIG=-config ../openSSL/openssl_sub.cfg

REM ### Sign request ###
openssl ca %SSLEAY_CONFIG% -policy policy_anything -md %PROVISIONING_SIGNATURE_ALGORITHM% -out %PROVISIONING_CERT_FILE% -infiles newreq.pem < yy.txt
if not %errorlevel%==0 goto sign_err

openssl x509 -in newcert.pem -inform PEM -out newcert.der -outform DER
if not %errorlevel%==0 goto convert_err

REM -- Convet to an MS CERT format (optional) --
REM openssl x509 -in newcert.pem -inform PEM -out newcert.x509.cer -outform PEM
endlocal
goto end

:nouuid
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_UUID variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo.
pause
set exitCode=1
goto end

:nohostname
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_HOSTNAME variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo.
pause
set exitCode=1
goto end

:nodomain
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_DOMAIN variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo.
pause
set exitCode=1
goto end

:nokeysize
echo Error, could not run batch:
echo %0 cannot continue because the PROVISIONING_RSA_KEY_BITS variable is not set
echo Note: The Configuration software sets this variable before calling this batch
echo.
pause
set exitCode=1
goto end

:req_err
echo.
echo Failure while creating request file, aborting.
echo.
pause
set exitCode=3
goto end

:sign_err
echo.
echo Failure while signing request file, aborting.
echo.
pause
set exitCode=3
goto end

:convert_err
echo.
echo Failure while converting certificate from PEM to DER, aborting.
echo.
pause
set exitCode=3
goto end

:end
if not %exitCode%==0 exit %exitCode%