@echo off
REM ---------------------------------------------------------------------------
REM
REM  Copyright (c) Intel Corporation, 2003 - 2009 All Rights Reserved.
REM
REM  File:      checkztc.bat
REM
REM  Contents:  A batch file which checks for the existence of a Root
REM		      certificate authority and creates one if necessary. 
REM		      Afterwards, it computes the root certificate hash and writes it 
REM		     into a file, creates ZTC certificate signed with the root certificate 
REM		     previously generated and generates a certificate chain contains the
REM		     root and ZTC certificates.
REM ----------------------------------------------------------------------------


REM ###########################################
REM ###											###
REM ### This batch is called by the Configuration Server program		###
REM ### in order to check if the  root CA is ready for use.    	   	###
REM ### you may customize this script and modify the defaults         	###
REM ### at your own risk.			                                              	###
REM ###                                                         				   	###
REM ###########################################

REM ----------------------------------------------------------------------
REM The following environment parameters can be customized.
REM Note that they need to be coordinated with the appropriate 
REM .conf.xml file in order to achieve properly working environment.
REM ----------------------------------------------------------------------
set CA_CRL_DISTRIBUTION_POINT=URI:http://crl.demoCA.com
set ZTC_CLIENT_CN=acme_app.intel.com
set ZTC_CLIENT_OU=Intel(R) Client Setup Certificate
set PKCS12_PASSWORD=qwerty
set CAKEY=.\rootKey.pem
set CACERT=.\rootCert.pem
set CADIR=.\rootCA
set ZTCDIR=.\ZTC
set ZTCCERT=.\ZTC_cert.pem
set ZTCKEY=.\ZTC_key.pem
set FULLCHAIN=.\FullChain.pem
REM ----------------------------------------------------------------------
set exitCode=0

set PATH=%PATH%;../openSSL

IF NOT EXIST "%CADIR%" goto createZtc
IF NOT EXIST "%ZTCDIR%" goto createZtc

echo Check ZTC Root CA and Cert passed

goto generateChain

:createZtc
echo Configuration server needs a ZTC certificate in order
echo to be able to set up Intel(R) AMT devices in PKI-CH method.
echo You can create demo Root CA and have it sign demo ZTC Certificate.
echo *NOTE* for enabling the certificate, you'll need to add the hash of the
echo created Root CA to FW Certitifcate Hash List.
set exitCode=2
yesno "Create a demo Root CA and use it to sign ZTC Certificate [Y/n] ?" Y
IF NOT errorlevel 1 goto end
set exitCode=0

set CALLER_WAITS_ON_EXIT=1
call start /WAIT rootCA_gen.bat
call start /WAIT ZTC_cert_req.bat
call start /WAIT ZTC_cert_sign.bat

:generateChain
set exitCode=1
IF NOT EXIST "%ZTCDIR%\private\%ZTCKEY%" goto missingZtcKey
IF NOT EXIST "%ZTCDIR%\%ZTCCERT%" goto missingZtcCert
IF NOT EXIST "%CADIR%\%CACERT%" goto missingRootCert

set exitCode=0
type %ZTCDIR%\private\%ZTCKEY% > %FULLCHAIN%
type %ZTCDIR%\%ZTCCERT% >> %FULLCHAIN%
type %CADIR%\%CACERT% >> %FULLCHAIN%

echo Generating certificate chain passed

goto end

:missingZtcKey
echo Failure while generating certificate chain: missing ZTC private key, aborting.
goto end

:missingZtcCert
echo Failure while generating certificate chain: missing ZTC Certificate, aborting.
goto end

:missingRootCert
echo Failure while generating certificate chain: missing Root Certificate, aborting.
goto end

:end
:exit %exitCode%